(function() {
    "use strict";

    // 案件情報アプリのアプリID
    var updateAppId = 116;

    /**
     * REST APIで一括更新するrecordsデータを作成する関数
     * @param records REST APIで一括取得したrecordsデータ
     * @returns {Array} REST APIで一括更新するrecordsデータ
     */

    function createPutRecords(records) {
        var putRecords = [];
        for (var i = 0, l = records.length; i < l; i++) {
            var record = records[i];
            putRecords[i] = {
                id: record['$id']['value'],
                revision: record['$revision']['value'],
                record: {
                    顧客名: {
                        value: record['顧客名']['value']
                    }
                }
            };
        }
        return putRecords;
    }

    /**
     * ルックアップを一括更新する関数
     * @param appId ルックアップの更新を行うアプリID
     * @param records 一括更新するrecordsデータ
     */

    function updateLookup(appId, records) {
        kintone.api(
            kintone.api.url('/k/v1/records', true),
            'PUT', {
                app: appId,
                records: records
            },
            function(resp) {
                alert('ルックアップの更新が完了しました!');
            }
        );
    }
    // 保存実行時イベント
    kintone.events.on(['app.record.edit.submit', 'app.record.index.edit.submit'], function(event) {
        // 案件情報アプリからレコードの一括取得(500件まで)
        kintone.api(
            kintone.api.url('/k/v1/records', true),
            'GET', {
                app: updateAppId,
                query: '顧客名 = "' + event.record['会社名']['value'] + '" limit 500'
            },
            function(resp) {
                var records = resp.records;
                // ルックアップの更新
                updateLookup(updateAppId, createPutRecords(records));
            }
        );
    });
})();